pub struct FilterGraphNode {
pub kept_by_optimizer: bool,
pub linear: bool,
pub inflate: i16,
pub inputs: Vec<FilterGraphPictureReference>,
pub subregion: LayoutRect,
}Fields
kept_by_optimizer: boolIndicates this graph node was marked as necessary by the DAG optimizer
linear: booltrue if color_interpolation_filter == LinearRgb; shader will convert sRGB texture pixel colors on load and convert back on store, for correct interpolation
inflate: i16padding for output rect if we need a border to get correct clamping, or to account for larger final subregion than source rect (see bug 1869672)
inputs: Vec<FilterGraphPictureReference>virtualized picture input bindings, these refer to other filter outputs by number within the graph, usually there is one element
subregion: LayoutRectclipping rect for filter node output